Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1343)

Unified Diff: third_party/WebKit/Source/platform/image-decoders/png/PNGImageDecoder.cpp

Issue 2857753002: Fix ImageAnimation constant names after Blink renaming (Closed)
Patch Set: Fix incorrect dependent CL Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/image-decoders/png/PNGImageDecoder.cpp
diff --git a/third_party/WebKit/Source/platform/image-decoders/png/PNGImageDecoder.cpp b/third_party/WebKit/Source/platform/image-decoders/png/PNGImageDecoder.cpp
index 9890b7c27a9479b1c639e0dabf838ec7922c3fff..0e12da8491b7094abc87fe1dd4647a97b07fd634 100644
--- a/third_party/WebKit/Source/platform/image-decoders/png/PNGImageDecoder.cpp
+++ b/third_party/WebKit/Source/platform/image-decoders/png/PNGImageDecoder.cpp
@@ -47,10 +47,10 @@ PNGImageDecoder::PNGImageDecoder(AlphaOption alpha_option,
: ImageDecoder(alpha_option, color_behavior, max_decoded_bytes),
offset_(offset),
current_frame_(0),
// It would be logical to default to kCAnimationNone, but BitmapImage uses
// that as a signal to never check again, meaning the actual count will
// never be respected.
- repetition_count_(kCAnimationLoopOnce),
+ repetition_count_(kAnimationLoopOnce),
has_alpha_channel_(false),
current_buffer_saw_alpha_(false) {}
@@ -122,7 +122,7 @@ void PNGImageDecoder::SetRepetitionCount(int repetition_count) {
}
int PNGImageDecoder::RepetitionCount() const {
- return Failed() ? kCAnimationLoopOnce : repetition_count_;
+ return Failed() ? kAnimationLoopOnce : repetition_count_;
}
void PNGImageDecoder::InitializeNewFrame(size_t index) {
@@ -47,10 +47,10 @@ PNGImageDecoder::PNGImageDecoder(AlphaOption alpha_option,
offset_(offset),
current_frame_(0),
- // It would be logical to default to kCAnimationNone, but BitmapImage uses
+ // It would be logical to default to kAnimationNone, but BitmapImage uses
// that as a signal to never check again, meaning the actual count will
// never be respected.

Powered by Google App Engine
This is Rietveld 408576698